/* gtkclock.c  -  GiwClock widget's source
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#ifndef __GIW_CLOCK_H__
#define __GIW_CLOCK_H__

#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GIW_TYPE_CLOCK                 (giw_clock_get_type ())
#define GIW_CLOCK(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_CLOCK, GiwClock))
#define GIW_CLOCK_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_CLOCK, GiwClockClass))
#define GIW_IS_CLOCK(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_CLOCK))
#define GIW_IS_CLOCK_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_CLOCK))
#define GIW_CLOCK_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_CLOCK, GiwClockClass))

typedef struct _GiwClock        GiwClock;
typedef struct _GiwClockClass   GiwClockClass;

struct _GiwClock
{
  GtkWidget widget;
  
  // Dimensions of clock components 
  gint radius;
  
  // Current angle, relative to east position (in radians)
  gdouble angle;
      
  // The size and position relative tho the widget window of the circle
  guint x, y, size;
 
  // Size of the ticks
  gint major_ticks_size, minor_ticks_size;
  
  // Time components (they are not real time components, they are only for drawing)
  gdouble hours, minutes, seconds;
  
  // The initial time, start counting before it
  GTimeVal zero;
  
  // True if the alarm in enabled, false for disable
  gboolean alarm;
  
  // Time of the alarm
  guint a_hours, a_minutes, a_seconds;

  // TRUE  if the clock is stopped
  gdouble stopped; 

  // The time of the clokc when it was stopped
  guint s_hours, s_minutes, s_seconds;

  // Gc for drawing seconds needle (red)
  GdkGC *s_needle_gc;

  // Gc for drawing hours ans minutes needles (bigger width)
  GdkGC *h_m_needle_gc;
};

struct _GiwClockClass
{
  GtkWidgetClass parent_class;
  
  void (* alarm) (GiwClock *clock); //Signal emited when the alarm time is reached
};

GtkWidget*     giw_clock_new                    (void);
guint          giw_clock_get_type               (void);
void           giw_clock_get_time               (GiwClock *clock, guint *hours, guint *minutes, guint *seconds);
void           giw_clock_set_time               (GiwClock *clock, guint hours, guint minutes, guint seconds);
void           giw_clock_enable_alarm           (GiwClock *clock, gboolean option); 
void           giw_clock_set_alarm              (GiwClock *clock, guint hours, guint minutes, guint seconds); 
void           giw_clock_stop                   (GiwClock *clock);
void           giw_clock_start                  (GiwClock *clock);


G_END_DECLS

#endif /* __GIW_CLOCK_H__ */
