/* gtkcompass.h  -  GiwCompass widget's header
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#ifndef __GIW_COMPASS_H__
#define __GIW_COMPASS_H__

#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GIW_TYPE_COMPASS                 (giw_compass_get_type ())
#define GIW_COMPASS(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_COMPASS, GiwCompass))
#define GIW_COMPASS_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_COMPASS, GiwCompassClass))
#define GIW_IS_COMPASS(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_COMPASS))
#define GIW_IS_COMPASS_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_COMPASS))
#define GIW_COMPASS_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_COMPASS, GiwCompassClass))

typedef struct _GiwCompass        GiwCompass;
typedef struct _GiwCompassClass   GiwCompassClass;

struct _GiwCompass
{
  GtkWidget widget;
  
  // Dimensions of compass components 
  gint radius;
  gint pointer_width, pointer_size;

  // Current angle, relative to north position (in radians)
  gfloat angle;
  
  // Button currently pressed or 0 if none
  guint8 button;
  
  // 0 for disable mouse using
  gboolean enable_mouse;
    
  // The characters wich represent the directions
  gchar north, east, south, west;
  
  // The layouts for draw the directions
  PangoLayout *directions[8];
  
  // The size and position of the circle relative tho the widget window 
  guint x, y, size;
   
  // Size of each directions layouts
  guint direction_width[8], direction_height[8];
  
  // The radius of the flower
  guint flower_radius;
  
  // Distance (in x or y axis) between the center and the location to draw the 2 characters directions
  guint dxy;

  // Gc for drawing the needle (red)
  GdkGC *needle_gc;
};

struct _GiwCompassClass
{
  GtkWidgetClass parent_class;
  
  void (* angle_changed) (GiwCompass *compass); //Signal emited when the angle is changed
};

GtkWidget*     giw_compass_new                    (void);
guint          giw_compass_get_type               (void);
gfloat         giw_compass_get_angle              (GiwCompass *compass);
void           giw_compass_set_angle              (GiwCompass *compass, gfloat angle);
void           giw_compass_set_directions         (GiwCompass *compass, guchar north, guchar south, guchar west, guchar east);
void           giw_compass_enable_mouse           (GiwCompass *compass, gboolean option);

G_END_DECLS

#endif /* __GIW_COMPASS_H__ */
