/* gtkdial.h  -  GiwDial widget's header
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/


#ifndef __GIW_DIAL_H__
#define __GIW_DIAL_H__

#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GIW_TYPE_DIAL                 (giw_dial_get_type ())
#define GIW_DIAL(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_DIAL, GiwDial))
#define GIW_DIAL_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_DIAL, GiwDialClass))
#define GIW_IS_DIAL(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_DIAL))
#define GIW_IS_DIAL_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_DIAL))
#define GIW_DIAL_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_DIAL, GiwDialClass))

typedef enum{
  GIW_DIAL_MOUSE_DISABLED,
  GIW_DIAL_MOUSE_AUTOMATICALLY,
  GIW_DIAL_MOUSE_DELAYED
}GiwDialMousePolicy;

typedef struct _GiwDial        GiwDial;
typedef struct _GiwDialClass   GiwDialClass;

struct _GiwDial
{
  GtkWidget widget;
  
  // Dimensions of dial components 
  gint e_radius, i_radius; // external radius, and internal radius
  gint needle_width, needle_size;

  // Current angle, relative to north position (in radians)
  gdouble angle;
  
  // Angle of the false-needle, used in the delayed mouse policy (phanton needle)
  gdouble phanton_angle;
  
  // Button currently pressed or 0 if none
  guint8 button;
    
  // Policy of mouse (GIW_DIAL_MOUSE_DISABLED, GIW_DIAL_MOUSE_AUTOMATICALLY, GIW_DIAL_MOUSE_DELAYED)
  gint mouse_policy;
    
  // The size and position relative tho the widget window of the circle
  guint x, y, size;
 
  // Number of major ticks, and how many minor ticks there will be between each major ticks
  guint major_ticks, minor_ticks;
  
  // Distance in radians between each major ticks, and between each minor ticks
  gdouble d_major_ticks, d_minor_ticks;
  
  // Size of the ticks
  gint major_ticks_size, minor_ticks_size;
  
  // Adjustment, that represents the value and his lower and upper value
  GtkAdjustment *adjustment;
  
  // Number of digits of the legends
  gint legends_digits;
  
  // Sizes of the legends
  gint legend_width, legend_height;
  
  // Distance between the center and the center of each legend layout 
  guint legend_radius;
  
  // The layouts of the legends
  PangoLayout **legends;
  
  // The font to draw the legends
  PangoFontDescription *legends_font;
  
  // The title's string
  gchar *title_str;
  
  // The title's layout
  PangoLayout *title;
  
  // The title's dimensions
  gint title_width, title_height;

  // Gc for the needle (red)
  GdkGC *needle_gc;
};

struct _GiwDialClass
{
  GtkWidgetClass parent_class;
};

GtkWidget*     giw_dial_new                    (GtkAdjustment *adjustment);
GtkWidget*     giw_dial_new_with_adjusment     (gdouble value, gdouble lower, gdouble upper);
guint          giw_dial_get_type               (void);
gdouble        giw_dial_get_value              (GiwDial *dial);
void           giw_dial_set_value              (GiwDial *dial, gdouble value);
void           giw_dial_set_adjustment         (GiwDial *dial, GtkAdjustment *adjustment);
GtkAdjustment* giw_dial_get_adjustment         (GiwDial *dial);
void           giw_dial_set_legends_digits     (GiwDial *dial, guint digits_number);
void           giw_dial_set_ticks_number       (GiwDial *dial, guint major, guint minor);
void           giw_dial_set_mouse_policy       (GiwDial *dial, GiwDialMousePolicy policy);
void           giw_dial_set_title              (GiwDial *dial, gchar *str);

G_END_DECLS

#endif /* __GIW_DIAL_H__ */
