/* giwshow.h  -  GiwShow widget's header
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/



#ifndef __GIW_SHOW_H__
#define __GIW_SHOW_H__

#include <gdk/gdk.h>
#include <gtk/gtkadjustment.h>
#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GIW_TYPE_SHOW                 (giw_show_get_type ())
#define GIW_SHOW(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_SHOW, GiwShow))
#define GIW_SHOW_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_SHOW, GiwShowClass))
#define GIW_IS_SHOW(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_SHOW))
#define GIW_IS_SHOW_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_SHOW))
#define GIW_SHOW_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_SHOW, GiwShowClass))

typedef struct _GiwShow        GiwShow;
typedef struct _GiwShowClass   GiwShowClass;

struct _GiwShow
{
  GtkWidget widget;
  
  // The radius of the external circle
  gint e_radius; 

  // The radius of the internal circle
  gint i_radius; 

  // The position of the external circle relative to the widget position (it will be outside of the widget area, because the hole circle don't stays inside the widget
  gint e_circle_x, e_circle_y;

  // The position of the internal circle relative to the widget position (can be outside of the widget area, because the hole circle don't stays inside the widget
  gint i_circle_x, i_circle_y;
  
  // Current angle, relative to north position (in radians)
  gdouble angle;
      
  // Number of major ticks, and how many minor ticks there will be between each major ticks
  guint major_ticks, minor_ticks;
  
  // Distance in radians between each major ticks, and between each minor ticks
  gdouble d_major_ticks, d_minor_ticks;
  
  // Size of the ticks
  gint major_ticks_size, minor_ticks_size;
  
  // Adjustment, that represents the value and his lower and upper value
  GtkAdjustment *adjustment;
  
  // Number of digits of the legends
  gint legends_digits;
  
  // Sizes of the legends
  gint legend_width, legend_height;
  
  // Distance between the center and the center of each legend layout 
  guint legend_radius;
  
  // The layouts of the legends
  PangoLayout **legends;
  
  // The font to draw the legends
  PangoFontDescription *legends_font;
  
  // The title's string
  gchar *title_str;
  
  // The title's layout
  PangoLayout *title;
  
  // The title's dimensions
  gint title_width, title_height;

  // Gc for drawing the needle
  GdkGC *needle_gc;
};

struct _GiwShowClass
{
  GtkWidgetClass parent_class;
};

GtkWidget*     giw_show_new                    (GtkAdjustment *adjustment);
GtkWidget*     giw_show_new_with_adjusment     (gdouble value, gdouble lower, gdouble upper);
guint          giw_show_get_type               (void);
gdouble        giw_show_get_value              (GiwShow *show);
void           giw_show_set_value              (GiwShow *show, gdouble value);
void           giw_show_set_adjustment         (GiwShow *show, GtkAdjustment *adjustment);
GtkAdjustment* giw_show_get_adjustment         (GiwShow *show);
void           giw_show_set_legends_digits     (GiwShow *show, guint digits_number);
void           giw_show_set_ticks_number       (GiwShow *show, guint major, guint minor);
void           giw_show_set_title              (GiwShow *show, gchar *str);

G_END_DECLS


#endif /* __GIW_SHOW_H__ */
