/* giwthermo.h  -  GiwThermo widget's header
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/



#ifndef __GIW_THERMO_H__
#define __GIW_THERMO_H__

#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GIW_TYPE_THERMO                 (giw_thermo_get_type ())
#define GIW_THERMO(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_THERMO, GiwThermo))
#define GIW_THERMO_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_THERMO, GiwThermoClass))
#define GIW_IS_THERMO(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_THERMO))
#define GIW_IS_THERMO_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_THERMO))
#define GIW_THERMO_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_THERMO, GiwThermoClass))

typedef enum{
  GIW_THERMO_MOUSE_DISABLED,
  GIW_THERMO_MOUSE_AUTOMATICALLY,
  GIW_THERMO_MOUSE_DELAYED
}GiwThermoMousePolicy;


typedef struct _GiwThermo        GiwThermo;
typedef struct _GiwThermoClass   GiwThermoClass;

struct _GiwThermo
{
  GtkWidget widget;

  GtkAdjustment *adjustment;
    
  gint major_ticks; // Number of major ticks in the thermo
  gint minor_ticks; // Number of minor ticks between each major ticks
  gint legend_digits; //Number of digits of the legend (counting the "." and the signal "-" if exists)
    
  //Options
  guint8 show_legends;
    
  // Button currently pressed or 0 if none
  guint8 button;
    
  // Policy of mouse (GIW_THERMO_MOUSE_DISABLED, GIW_THERMO_MOUSE_AUTOMATICALLY, GIW_THERMO_MOUSE_DELAYED)
  gint mouse_policy;
    
  // For drawing:

  /* The thermometer is represented by a rectangle where the column is, and a border. This rectangle is the i_box (internal box), and this rectangle plus the borders is the e_box (external_box)*/
  
  // e_box size and position (relative to the widget's window corner)
  gint e_box_height, e_box_width; 
  gint e_box_x, e_box_y; 

  // i_box size and position (relative to the widget's window corner)
  gint i_box_height, i_box_width; 
  gint i_box_x, i_box_y; 
  
  // The height of the column (wich is proporcional to the value, or temperature)
  gint column_height;

  // The height of the phantom column (the column wich appear when the mouse policy is delayed)
  gint p_column_height; 

  //Space between major ticks
  gdouble major_dy; 

  //Space between minor ticks
  gdouble minor_dy;

  //  Legends size
  gint legends_width, legends_height;
  
  // All the layouts of all the legends
  PangoLayout **legends; 

  // GC for drawing the column  
  GdkGC *column_gc; 
};

struct _GiwThermoClass
{
  GtkWidgetClass parent_class;
};

GtkWidget*     giw_thermo_new                    (GtkAdjustment *adjustment);
GtkWidget*     giw_thermo_new_with_adjustment    (gdouble value, gdouble lower, gdouble upper);
guint          giw_thermo_get_type               (void);
void           giw_thermo_set_value              (GiwThermo *thermo, gdouble value);   
gdouble        giw_thermo_get_value              (GiwThermo *thermo);   
GtkAdjustment *giw_thermo_get_adjustment         (GiwThermo *thermo);
void           giw_thermo_set_adjustment         (GiwThermo *thermo, GtkAdjustment *adjustment);
void           giw_thermo_set_legends_digits      (GiwThermo *thermo, gint digits);
void           giw_thermo_show_legends           (GiwThermo *thermo, guchar option);
void           giw_thermo_set_mouse_policy       (GiwThermo *thermo, GiwThermoMousePolicy policy);
void           giw_thermo_set_major_ticks_number (GiwThermo *thermo, gint number);
void           giw_thermo_set_minor_ticks_number (GiwThermo *thermo, gint number);

G_END_DECLS

#endif /* __GIW_THERMO_H__ */
