/* giwxyplot.h  -  GiwXYPlot widget's header
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/



#ifndef __GIW_XYPLOT_H__
#define __GIW_XYPLOT_H__

#include <gdk/gdk.h>
#include <gtk/gtkwidget.h>

typedef enum
{
  GIW_XYPLOT_HMAJOR_GRID,
  GIW_XYPLOT_HMINOR_GRID,
  GIW_XYPLOT_VMAJOR_GRID,
  GIW_XYPLOT_VMINOR_GRID
} GiwXYPlotGrid;

G_BEGIN_DECLS

#define GIW_TYPE_XYPLOT                 (giw_xyplot_get_type ())
#define GIW_XYPLOT(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIW_TYPE_XYPLOT, GiwXYPlot))
#define GIW_XYPLOT_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), GIW_TYPE_XYPLOT, GiwXYPlotClass))
#define GIW_IS_XYPLOT(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIW_TYPE_XYPLOT))
#define GIW_IS_XYPLOT_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), GIW_TYPE_XYPLOT))
#define GIW_XYPLOT_GET_CLASS(obj)       (G_TYPE_INSTANCE_GET_CLASS ((obj), GIW_TYPE_XYPLOT, GiwXYPlotClass))

typedef enum{
  GIW_XYPLOT_DATA_LINES,
  GIW_XYPLOT_DATA_POINTS,
  GIW_XYPLOT_DATA_LINES_AND_POINTS
}GiwXYPlotDataStyle;

// Structure to manage the data
typedef struct 
{
  gdouble *x, *y;
  guint size;

  GiwXYPlotDataStyle style;

  guint p_width, l_width;
  GdkColor p_color, l_color;
  GdkLineStyle line_style;
}XYPlotData;

typedef struct _GiwXYPlot        GiwXYPlot;
typedef struct _GiwXYPlotClass   GiwXYPlotClass;

struct _GiwXYPlot
{
  GtkWidget widget;
  
  gdouble xmin, xmax, ymin, ymax; // The range
  
  // For drawing

  // Pixmap to draw the data
  GdkPixmap *plotting_area; 
  // Rectangle do define the area where the plot will be
  GdkRectangle plotting_rect;
  // Number of digits to be used to draw the legends
  guint legends_digits; 
  // Number of major ticks, and minor ticks between each major tick
  guint hmajor_ticks, hminor_ticks; 
  // (horizontal and vertical)
  guint vmajor_ticks, vminor_ticks; 
  // Distance between each horizontal major and minor ticks
  gdouble d_hmajor, d_hminor; 
  // Distance between each vertical major and minor ticks 
  gdouble d_vmajor, d_vminor; 
  // The diference of value between each legend
  gdouble d_hlegend, d_vlegend; 
  
  // GC for drawing the background of the plotting area
  GdkGC *back_gc; 

  // The layouts of the legends
  PangoLayout **h_legends;
  PangoLayout **v_legends;

  // The legend's dimensions
  gint legends_width, legends_height;
  
  // GC to store the line attributes used to draw the grids (linestyle, color and width)
  GdkGC *hmajor_grid_gc, *hminor_grid_gc, *vmajor_grid_gc, *vminor_grid_gc;
  gboolean hmajor_grid, hminor_grid, vmajor_grid, vminor_grid; // Enable os disable grid

  // Variables to manage the data
  
  // The linked list wit hthe data struct's pointers
  GList *data_list;
  // Quantity of data in the list
  guint data_amount;
  // GC to draw the datas
  GdkGC *data_gc;

  // Variables to deal with the mouse

  guint mouse_button; // To know wich button was pressed
  
  // To configure the zoom with mouse button
  //True to enable 
  gboolean mouse_zoom_enabled;
  // The mouse button to use
  guint mouse_zoom_button;
  // The coordinates of the zoom's inital clicked point
  GdkPoint zoom_point;
  // The zoom's rectangle (ralative to the window)
  GdkRectangle zoom_rect;

  // Variables to configure the displacement of the plot with the mouse
  // True to enable
  gboolean mouse_displace_enabled;
  // The mouse button to use
  guint mouse_displace_button;
  // The last point where were the mouse, to calculate the amount to move the screen
  GdkPoint move_point;

  // Variables to configure the zoom with the wheel
  // True to enable   
  gboolean wheel_zoom_enabled;
  // The nuber wich will be multiplied/divided by the current range to get the new range
  gdouble wheel_zoom_factor;

  // Variables to configure the option of setting autorange for the plot using some mouse button
  // True to enable
  gboolean mouse_autorange_enabled;
  // The mouse button to use
  guint mouse_autorange_button;
};

struct _GiwXYPlotClass
{
  GtkWidgetClass parent_class;
};

GtkWidget*     giw_xyplot_new                    (void);
guint          giw_xyplot_get_type               (void);
void           giw_xyplot_set_range              (GiwXYPlot *xyplot, gdouble xmin, gdouble xmax, gdouble ymin, gdouble ymax);    
void           giw_xyplot_set_autorange          (GiwXYPlot *xyplot, XYPlotData *data);    
void           giw_xyplot_get_range              (GiwXYPlot *xyplot, gdouble *xmin, gdouble *xmax, gdouble *ymin, gdouble *ymax);
void           giw_xyplot_get_point              (GiwXYPlot *xyplot, guint x, guint y, gdouble *xv, gdouble *yv);
void           giw_xyplot_set_ticks              (GiwXYPlot *xyplot, guint hmajor, guint hminor, guint vmajor, guint vminor);
void           giw_xyplot_get_ticks              (GiwXYPlot *xyplot, guint *hmajor, guint *hminor, guint *vmajor, guint *vminor);
void           giw_xyplot_set_legends_digits     (GiwXYPlot *xyplot, guint digits);
guint          giw_xyplot_get_legends_digits     (GiwXYPlot *xyplot);
void           giw_xyplot_set_background_color   (GiwXYPlot *xyplot, GdkColor color); 
void           giw_xyplot_set_grids_attributes   (GiwXYPlot *xyplot, GiwXYPlotGrid grid, GdkColor color, gint line_width, GdkLineStyle line_style);
void           giw_xyplot_get_grids_attributes   (GiwXYPlot *xyplot, GiwXYPlotGrid grid, GdkColor *color, gint *line_width, GdkLineStyle *line_style);
void           giw_xyplot_enable_grids           (GiwXYPlot *xyplot, GiwXYPlotGrid grid, gboolean enable);
void           giw_xyplot_add_data               (GiwXYPlot *xyplot, XYPlotData *data);
void           giw_xyplot_remove_data            (GiwXYPlot *xyplot, XYPlotData *data);
void           giw_xyplot_configure_mouse_zoom   (GiwXYPlot *xyplot, gboolean enabled, guint button);
void           giw_xyplot_configure_wheel_zoom   (GiwXYPlot *xyplot, gboolean enabled, gdouble factor);
void           giw_xyplot_configure_mouse_displace(GiwXYPlot *xyplot, gboolean enabled, guint button);
void           giw_xyplot_configure_mouse_autorange(GiwXYPlot *xyplot, gboolean enabled, guint button);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GIW_XYPLOT_H__ */
