/* clock_full_example.c  -  GiwClock widget's full example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <giwclock.h> 

GtkWidget *window;
GtkWidget *table1;

GtkWidget *frame_clock;
GtkWidget *gclock;

GtkWidget *frame_get_time;
GtkWidget *vbox_get_time;
GtkWidget *label_time;
GtkWidget *button_get_time;

GtkWidget *frame_set_time;
GtkWidget *table_set_time;
GtkWidget *label_hours;
GtkWidget *spin_hours;
GtkWidget *label_minutes;
GtkWidget *spin_minutes;
GtkWidget *label_seconds;
GtkWidget *spin_seconds;
GtkWidget *button_set_time;

GtkWidget *frame_stop_start;
GtkWidget *vbox_stop_start;
GtkWidget *button_stop;
GtkWidget *button_start;

GtkWidget *frame_set_alarm;
GtkWidget *table_set_alarm;
GtkWidget *label_ahours;
GtkWidget *label_aminutes;
GtkWidget *label_aseconds;
GtkWidget *spin_ahours;
GtkWidget *spin_aminutes;
GtkWidget *spin_aseconds;
GtkWidget *button_set_alarm;
GtkWidget *toggle_alarm;

void button_stop_clicked(GtkButton *button, gpointer user_data)
{
	giw_clock_stop(GIW_CLOCK(gclock));
}

void button_start_clicked(GtkButton *button, gpointer user_data)
{
	giw_clock_start(GIW_CLOCK(gclock));
}

void button_get_time_clicked(GtkButton *button, gpointer user_data)
{
	unsigned int hours, minutes, seconds;
	char str[14];
	
	giw_clock_get_time(GIW_CLOCK(gclock), &hours, &minutes, &seconds);
	sprintf(str, "%d : %d : %d", hours, minutes, seconds);
	gtk_label_set_text(GTK_LABEL(label_time), str);
}

void button_set_time_clicked(GtkButton *button, gpointer user_data)
{
	int hours, minutes, seconds;
	
	hours=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_hours));
	minutes=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_minutes));
	seconds=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_seconds));
		
	giw_clock_set_time(GIW_CLOCK(gclock), hours, minutes, seconds);
}

void button_set_alarm_clicked(GtkButton *button, gpointer user_data)
{
	int hours, minutes, seconds;
	
	hours=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_ahours));
	minutes=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_aminutes));
	seconds=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_aseconds));
		
	giw_clock_set_alarm(GIW_CLOCK(gclock), hours, minutes, seconds);
}

void toggle_alarm_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
	giw_clock_enable_alarm(GIW_CLOCK(gclock), gtk_toggle_button_get_active(togglebutton));
}

void clock_alarm(GiwClock *gclock, gpointer user_data)
{
	printf("Alarm!!!!!\n"); 
	fflush(stdout);
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle_alarm), FALSE);
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);

	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  
	gtk_window_set_title (GTK_WINDOW (window), "GiwClock Full Example");
  
	gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	gtk_container_border_width (GTK_CONTAINER (window), 10);
	
	// Table with for cells to hold the four frames
	table1=gtk_table_new(2, 3, FALSE);
	gtk_container_add(GTK_CONTAINER(window), table1);
	gtk_widget_show(table1);
  
	// The frame with the clock and the label to view time
	frame_clock=gtk_frame_new("Clock:");
	gtk_table_attach(GTK_TABLE(table1), frame_clock, 0, 1, 0, 1, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
	gtk_widget_show(frame_clock);
  
	gclock=giw_clock_new();
	gtk_container_add(GTK_CONTAINER(frame_clock), gclock);
	gtk_widget_show (gclock);

	// Frame with the label to view time and the button to get it
	frame_get_time=gtk_frame_new("Get time:");
	gtk_table_attach(GTK_TABLE(table1), frame_get_time, 0, 1, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
	gtk_widget_show(frame_get_time);

	vbox_get_time=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(frame_get_time), vbox_get_time);
	gtk_widget_show(vbox_get_time);
	
	label_time=gtk_label_new("0 : 0 : 0");
	gtk_box_pack_start(GTK_BOX(vbox_get_time), label_time, TRUE, TRUE, 0);
	gtk_widget_show(label_time); 
	
	button_get_time=gtk_button_new_with_label("Get time!");
	gtk_box_pack_start(GTK_BOX(vbox_get_time), button_get_time, TRUE, TRUE, 0);
	gtk_widget_show(button_get_time);

	// Frame with the labels, spins and the button to set time
	frame_set_time=gtk_frame_new("Set time:");
	gtk_table_attach(GTK_TABLE(table1), frame_set_time, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
	gtk_widget_show(frame_set_time);

	table_set_time=gtk_table_new(4, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_set_time), table_set_time);
	gtk_widget_show(table_set_time);
	
	label_hours=gtk_label_new("Hours: ");
	gtk_table_attach(GTK_TABLE(table_set_time), label_hours, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_hours); 
	
	spin_hours=gtk_spin_button_new_with_range(0, 23, 1);
	gtk_table_attach(GTK_TABLE(table_set_time), spin_hours, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_hours);
	
	label_minutes=gtk_label_new("Minutes: ");
	gtk_table_attach(GTK_TABLE(table_set_time), label_minutes, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_minutes); 
	
	spin_minutes=gtk_spin_button_new_with_range(0, 59, 1);
	gtk_table_attach(GTK_TABLE(table_set_time), spin_minutes, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_minutes);
	
	label_seconds=gtk_label_new("Seconds: ");
	gtk_table_attach(GTK_TABLE(table_set_time), label_seconds, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_seconds); 
	
	spin_seconds=gtk_spin_button_new_with_range(0, 59, 1);
	gtk_table_attach(GTK_TABLE(table_set_time), spin_seconds, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_seconds);
	
	button_set_time=gtk_button_new_with_label("Set time!");
	gtk_table_attach(GTK_TABLE(table_set_time), button_set_time, 0, 2, 3, 4, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(button_set_time);

	// Frame with hold the start and stop buttons
	frame_stop_start=gtk_frame_new("Stop/Start:");
	gtk_table_attach(GTK_TABLE(table1), frame_stop_start, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
	gtk_widget_show(frame_stop_start);

	vbox_stop_start=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(frame_stop_start), vbox_stop_start);
	gtk_widget_show(vbox_stop_start);
	
	button_stop=gtk_button_new_with_label("Stop clock");
	gtk_box_pack_start(GTK_BOX(vbox_stop_start), button_stop, TRUE, TRUE, 0);
	gtk_widget_show(button_stop);

	button_start=gtk_button_new_with_label("Start clock");
	gtk_box_pack_start(GTK_BOX(vbox_stop_start), button_start, TRUE, TRUE, 0);
	gtk_widget_show(button_start);

	// Frame with the labels, spins and the button to set the alarm
	frame_set_alarm=gtk_frame_new("Set alarm:");
	gtk_table_attach(GTK_TABLE(table1), frame_set_alarm, 2, 3, 0, 2, GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
	gtk_widget_show(frame_set_alarm);

	table_set_alarm=gtk_table_new(5, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_set_alarm), table_set_alarm);
	gtk_widget_show(table_set_alarm);
	
	label_ahours=gtk_label_new("Alarm hours: ");
	gtk_table_attach(GTK_TABLE(table_set_alarm), label_ahours, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_ahours); 
	
	spin_ahours=gtk_spin_button_new_with_range(0, 24, 1);
	gtk_table_attach(GTK_TABLE(table_set_alarm), spin_ahours, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_ahours);
	
	label_aminutes=gtk_label_new("Alarm minutes: ");
	gtk_table_attach(GTK_TABLE(table_set_alarm), label_aminutes, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_aminutes); 
	
	spin_aminutes=gtk_spin_button_new_with_range(0, 59, 1);
	gtk_table_attach(GTK_TABLE(table_set_alarm), spin_aminutes, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_aminutes);
	
	label_aseconds=gtk_label_new("Alarm seconds: ");
	gtk_table_attach(GTK_TABLE(table_set_alarm), label_aseconds, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_aseconds); 
	
	spin_aseconds=gtk_spin_button_new_with_range(0, 59, 1);
	gtk_table_attach(GTK_TABLE(table_set_alarm), spin_aseconds, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_aseconds);
	
	button_set_alarm=gtk_button_new_with_label("Set Alarm!");
	gtk_table_attach(GTK_TABLE(table_set_alarm), button_set_alarm, 0, 2, 3, 4, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(button_set_alarm);

	toggle_alarm=gtk_toggle_button_new_with_label("Enable Alarm");
	gtk_table_attach(GTK_TABLE(table_set_alarm), toggle_alarm, 0, 2, 4, 5, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(toggle_alarm);

	g_signal_connect(G_OBJECT(button_stop), "clicked", G_CALLBACK(button_stop_clicked), NULL);	
	g_signal_connect(G_OBJECT(button_start), "clicked", G_CALLBACK(button_start_clicked), NULL);	

	g_signal_connect(G_OBJECT(button_get_time), "clicked", G_CALLBACK(button_get_time_clicked), NULL);
	g_signal_connect(G_OBJECT(button_set_time), "clicked", G_CALLBACK(button_set_time_clicked), NULL);
	g_signal_connect(G_OBJECT(button_set_alarm), "clicked", G_CALLBACK(button_set_alarm_clicked), NULL);
	g_signal_connect(G_OBJECT(toggle_alarm), "toggled", G_CALLBACK(toggle_alarm_toggled), NULL);
		
	g_signal_connect(G_OBJECT(gclock), "alarm", G_CALLBACK(clock_alarm), NULL);
	
	gtk_widget_show (window);
  
	gtk_main ();
  
	return 0;
}
