/* compass_full_example.c  -  A GiwCompass full example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <math.h>
#include <giwcompass.h>

GtkWidget *window;
GtkWidget *compass;
GtkWidget *vbox;
GtkWidget *spin;
GtkWidget *enable_button;
GtkWidget *north_entry;
GtkWidget *south_entry;
GtkWidget *east_entry;
GtkWidget *west_entry;
GtkWidget *symbols_button;
GtkWidget *label;
GtkWidget *separator;

void spin_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// So, the spin value was changed, then, let's gonna set the angle of the compass to the new spin value
	giw_compass_set_angle(GIW_COMPASS(compass), gtk_spin_button_get_value(spinbutton));
}

void compass_changed_angle(GiwCompass *compass, gpointer user_data)
{
	// So, the compass angle was changed, then, let's gonna set the value of the spin to the new compass angle
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin), giw_compass_get_angle(GIW_COMPASS(compass)));
}

void enable_button_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
	// Set the opion of mouse using as the mode of the toggle button
	giw_compass_enable_mouse(GIW_COMPASS(compass), gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(enable_button)));
}

void symbols_button_clicked(GtkButton *button, gpointer user_data)
{
	char north, south, east, west;
	
	// Now let's change the symbols of the compass
	
	// Taking the symbols from the entrys
	north=(gtk_entry_get_text(GTK_ENTRY(north_entry)))[0];
	south=(gtk_entry_get_text(GTK_ENTRY(south_entry)))[0];
	east=(gtk_entry_get_text(GTK_ENTRY(east_entry)))[0];
	west=(gtk_entry_get_text(GTK_ENTRY(west_entry)))[0];

	// Setting the symbols of the compass
	giw_compass_set_directions(GIW_COMPASS(compass), north, south, west, east);
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);

	// Creating the windows to hold all the widgets	
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  
	gtk_window_set_title (GTK_WINDOW (window), "GiwCompass Full Example");
  
	gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	gtk_container_border_width (GTK_CONTAINER (window), 10);

	vbox = gtk_vbox_new (FALSE, 5);
	gtk_container_add (GTK_CONTAINER (window), vbox);
	gtk_widget_show(vbox);
  
	// The compass widget, created like any other convencional widget
	compass = giw_compass_new();
	gtk_box_pack_start (GTK_BOX(vbox), compass, TRUE, TRUE, 0);
	gtk_widget_show (compass);
  
	label=gtk_label_new("Angle (radians):");
	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
	gtk_widget_show(label);
	
	// Spin button that will show and change the angle of the compass
	spin = gtk_spin_button_new_with_range(0, 2*M_PI, 0.1);
	gtk_box_pack_start (GTK_BOX(vbox), spin, TRUE, TRUE, 0);
	gtk_widget_show (spin);
	
	// Button that will enable or disable changing value of the compass by mouse
	enable_button=gtk_toggle_button_new_with_label("Enable Mouse");
  	gtk_box_pack_start(GTK_BOX(vbox), enable_button, TRUE, TRUE, 0);
	gtk_widget_show(enable_button);
	
	separator=gtk_hseparator_new();
	gtk_box_pack_start(GTK_BOX(vbox), separator, TRUE, TRUE, 0);
	gtk_widget_show(separator);
	
	// The entry's that will set the synbols of the direction of the compass
	label=gtk_label_new("North Symbol");
	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
	gtk_widget_show(label);
	
	north_entry=gtk_entry_new_with_max_length(1);
	gtk_box_pack_start(GTK_BOX(vbox), north_entry, TRUE, TRUE, 0);
	gtk_widget_show(north_entry);
	
	label=gtk_label_new("South Symbol");
	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
	gtk_widget_show(label);
	
	south_entry=gtk_entry_new_with_max_length(1);
	gtk_box_pack_start(GTK_BOX(vbox), south_entry, TRUE, TRUE, 0);
	gtk_widget_show(south_entry);
	
	label=gtk_label_new("East Symbol");
	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
	gtk_widget_show(label);
	
	east_entry=gtk_entry_new_with_max_length(1);
	gtk_box_pack_start(GTK_BOX(vbox), east_entry, TRUE, TRUE, 0);
	gtk_widget_show(east_entry);
	
	label=gtk_label_new("West Symbol");
	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
	gtk_widget_show(label);
	
	west_entry=gtk_entry_new_with_max_length(1);
	gtk_box_pack_start(GTK_BOX(vbox), west_entry, TRUE, TRUE, 0);
	gtk_widget_show(west_entry);
	
	// Button to set the symbols in the entry's
	symbols_button=gtk_button_new_with_label("Change Symbols");
	gtk_box_pack_start(GTK_BOX(vbox), symbols_button, TRUE, TRUE, 0);
	gtk_widget_show(symbols_button);
	
	// Putting the initial default symbols
	gtk_entry_set_text(GTK_ENTRY(north_entry), "N");
	gtk_entry_set_text(GTK_ENTRY(south_entry), "S");
	gtk_entry_set_text(GTK_ENTRY(east_entry), "E");
	gtk_entry_set_text(GTK_ENTRY(west_entry), "W");
		
	// With this callback, every time spin value is changed,the angle of the compass is changed too
	g_signal_connect(G_OBJECT(spin), "value-changed", G_CALLBACK(spin_changed_value), NULL);
	
	// With this callback, every time compass angle is changed,the value of the spin is changed too
	g_signal_connect(G_OBJECT(compass), "angle-changed", G_CALLBACK(compass_changed_angle), NULL);
	
	// Callback to enable or disable mouse
	g_signal_connect(G_OBJECT(enable_button), "toggled", G_CALLBACK(enable_button_toggled), NULL);
	
	// Callback to set the compass direction's symbos
	g_signal_connect(G_OBJECT(symbols_button), "clicked", G_CALLBACK(symbols_button_clicked), NULL);
  
	//Showing everything
	gtk_widget_show (window);
  
	gtk_main ();
  
	return(0);
}
