/* compass_simple_example.c  -  A GiwCompass simple example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <math.h>
#include <giwcompass.h> 

GtkWidget *window;
GtkWidget *compass;

void compass_motion_notify(GtkWidget *widget, GdkEventMotion *event, gpointer user_data)
{
	int x, y, dx, dy;
	double angle;

	// Getting the mouse position
	if (event->is_hint){
		gtk_widget_get_pointer(widget, &x, &y);
	}else{
		x=event->x;
		y=event->y;
	}
	
	// Calculating distance between pointer and the center of the compass widget
	dx=x-(compass->allocation.x+compass->allocation.width/2);
	dy=(compass->allocation.y+compass->allocation.height/2)-y;
	
	// Now, with the arc tangent (atan2) we now the angle (radians)
	angle=atan2((double)dy, (double)dx);
	
	// Setting the angle of the compass, putting it in mouse direction
	giw_compass_set_angle(GIW_COMPASS(compass), angle);
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);

	// Creating the window
	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_widget_set_events(window, GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | gtk_widget_get_events(window));
    
	gtk_window_set_title (GTK_WINDOW (window), "GiwCompass Simple Example");
  
	gtk_signal_connect (GTK_OBJECT (window), "destroy",
		      GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	gtk_container_border_width(GTK_CONTAINER(window), 10);
  
	// Now, creates the compass with the funciont giw_compass_new
	compass=giw_compass_new();
	// Put the compass into the window
	gtk_container_add(GTK_CONTAINER(window), compass);
	// Show the compass widget
	gtk_widget_show(compass);
    
	// Callback to receive every time mouse moves
	g_signal_connect(G_OBJECT(compass), "motion-notify-event", G_CALLBACK(compass_motion_notify), NULL);
  
	// Show the window with the size of 400x400
	gtk_widget_show (window);
	gtk_window_resize(GTK_WINDOW(window), 400, 400);
  
	gtk_main();
  
	return(0);
}
