/* led_full_example.c  -  GiwLed full example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <giwled.h> 

GtkWidget *window;
GtkWidget *led;
GtkWidget *vbox;
GtkWidget *button1;
GtkWidget *button2;
GtkWidget *button_enable_mouse;
GtkWidget *button_on_color;
GtkWidget *button_off_color;
GdkColor color_on, color_off;

gboolean button1_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
{
	// Set on
	giw_led_set_mode(GIW_LED(led), TRUE);
    
    return TRUE;
}

gboolean button2_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
{
	// Set off
	giw_led_set_mode(GIW_LED(led), FALSE);
    
    return TRUE;
}

gboolean button_on_color_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
{
	GtkWidget *dialog;
	GtkColorSelection *colorsel;
	gint response;
	GdkColor color;
  
	// Creating the dialog and getting the chosen color
	
	dialog = gtk_color_selection_dialog_new ("Changing color");

	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
  
	colorsel = GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel);

	response = gtk_dialog_run (GTK_DIALOG (dialog));

	if (response == GTK_RESPONSE_OK){
		gtk_color_selection_get_current_color (colorsel, &color);

		// Updating the on color
		color_on=color;
		giw_led_set_colors(GIW_LED(led), color_on, color_off);
	}
  
	gtk_widget_destroy (dialog);
    
    return TRUE;   
}

gboolean button_off_color_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
{
	GtkWidget *dialog;
	GtkColorSelection *colorsel;
	gint response;
	GdkColor color;
	
	// Creating the dialog and getting the chosen color
  
	dialog = gtk_color_selection_dialog_new ("Changing color");

	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
  
	colorsel = GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel);

	response = gtk_dialog_run (GTK_DIALOG (dialog));

	if (response == GTK_RESPONSE_OK){
		gtk_color_selection_get_current_color (colorsel, &color);

		// Updating the off color
		color_off=color;
		giw_led_set_colors(GIW_LED(led), color_on, color_off);
	}
  
	gtk_widget_destroy (dialog);
    
    return TRUE;
}

void button_enable_mouse_toggled(GtkToggleButton *button, gpointer user_data)
{
	giw_led_enable_mouse(GIW_LED(led), gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
}

void led_mode_changed(GiwLed *led, gpointer user_data)
{
	printf("Mode changed\n");
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);
     
	// The main window, holding the other widgets
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  
	gtk_window_set_title (GTK_WINDOW (window), "GiwLed Full Example");
  
	gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	gtk_container_border_width (GTK_CONTAINER (window), 10);

	vbox = gtk_vbox_new (TRUE, 5);
	gtk_container_add (GTK_CONTAINER (window), vbox);
	gtk_widget_show(vbox);
    
	// Creating the led
	led = giw_led_new();
	gtk_box_pack_start (GTK_BOX (vbox), led, FALSE, FALSE, 0);
	gtk_widget_show (led);
  
	// The button to set on the led 
	button1 = gtk_button_new_with_label("Set on");
	gtk_box_pack_start (GTK_BOX (vbox), button1, FALSE, FALSE, 0);
	gtk_widget_show (button1);
  
	// The button to set off the led 
	button2 = gtk_button_new_with_label("Set off");
	gtk_box_pack_start (GTK_BOX (vbox), button2, FALSE, FALSE, 0);
	gtk_widget_show (button2);
	
	// The button to enable or disable the mouse in the led
	button_enable_mouse = gtk_toggle_button_new_with_label("Enable Mouse");
	gtk_box_pack_start (GTK_BOX (vbox), button_enable_mouse, FALSE, FALSE, 0);
	gtk_widget_show (button_enable_mouse);
	
	// Button to choose the color of the on mode
	button_on_color = gtk_button_new_with_label("Set on color");
	gtk_box_pack_start (GTK_BOX (vbox), button_on_color, FALSE, FALSE, 0);
	gtk_widget_show (button_on_color);
	
	// Button to choose the color of the off mode
	button_off_color = gtk_button_new_with_label("Set off color");
	gtk_box_pack_start (GTK_BOX (vbox), button_off_color, FALSE, FALSE, 0);
	gtk_widget_show (button_off_color);
	
	// Setting initial colors
	color_on.red=0;
	color_on.blue=0;
	color_on.green=65355; 
	color_off.red=0;
	color_off.blue=0;
	color_off.green=0; 
	giw_led_set_colors(GIW_LED(led), color_on, color_off);

	// Connecting signals
	g_signal_connect (G_OBJECT (button1), "clicked", G_CALLBACK (button1_press), NULL);
	g_signal_connect (G_OBJECT (button2), "clicked", G_CALLBACK (button2_press), NULL);
	g_signal_connect (G_OBJECT (button_on_color), "clicked", G_CALLBACK (button_on_color_press), NULL);
	g_signal_connect (G_OBJECT (button_off_color), "clicked", G_CALLBACK (button_off_color_press), NULL);
	g_signal_connect(G_OBJECT(button_enable_mouse), "toggled", G_CALLBACK(button_enable_mouse_toggled), NULL);
	g_signal_connect (G_OBJECT (led), "mode_changed", G_CALLBACK (led_mode_changed), NULL);
  
	gtk_widget_show (window);
    
	gtk_main ();
  
	return(0);
}
