/* tank_full_example.c  -  GiwTank full example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <giwtank.h> 

GtkWidget *window;
GtkWidget *hbox1;

GtkWidget *frame_tank;
GtkWidget *vbox_tank;
GtkWidget *tank;
GtkWidget *spin_value;

GtkWidget *frame_config;
GtkWidget *table_config;
GtkWidget *label_major;
GtkWidget *spin_major;
GtkWidget *label_minor;
GtkWidget *spin_minor;
GtkWidget *label_legends_digits;
GtkWidget *spin_legends_digits;
GtkWidget *toggle_button_legends;

GtkWidget *vbox1;

GtkWidget *frame_adj;
GtkWidget *table_adj;
GtkWidget *label_adj_value;
GtkWidget *spin_adj_value;
GtkWidget *label_adj_lower;
GtkWidget *spin_adj_lower;
GtkWidget *label_adj_upper;
GtkWidget *spin_adj_upper;
GtkWidget *button_set_adj;

void spin_major_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new major ticks number
	giw_tank_set_major_ticks_number(GIW_TANK(tank), gtk_spin_button_get_value(spinbutton));
}

void spin_minor_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new minor ticks number
	giw_tank_set_minor_ticks_number(GIW_TANK(tank), gtk_spin_button_get_value(spinbutton));
}

void spin_legends_digits_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new legends digits number
	giw_tank_set_legends_digits(GIW_TANK(tank), gtk_spin_button_get_value(spinbutton));
}

void toggle_button_legends_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
	// Showing/hiding legends
	giw_tank_show_legends(GIW_TANK(tank), gtk_toggle_button_get_active(togglebutton));
}

void button_set_adj_clicked(GtkButton *button, gpointer user_data)
{
	GtkObject *adj;
	gdouble value , lower, upper;
	
	// Getting the new adjustment paramenters
	value=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_value));
	lower=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_lower));
	upper=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_upper));
	
	adj=gtk_adjustment_new(value, lower, upper, 1.0, 1.0, 1.0);
	// Setting the new adjustment in the tank and the spin_value
	giw_tank_set_adjustment(GIW_TANK(tank), GTK_ADJUSTMENT(adj));
	gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON(spin_value), GTK_ADJUSTMENT(adj));
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_value), GTK_ADJUSTMENT(adj)->value);
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);

	// The main window
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);

	gtk_window_set_title(GTK_WINDOW(window), "GiwTank Full Example");

	gtk_window_resize(GTK_WINDOW(window), 300, 300);
    
	gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	hbox1=gtk_hbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), hbox1);
	gtk_widget_show(hbox1);
	
	// Frame to the tank 
	frame_tank=gtk_frame_new("Tank:");
	gtk_box_pack_start(GTK_BOX(hbox1), frame_tank, TRUE, TRUE, 0);
	gtk_widget_show(frame_tank);
	
	vbox_tank=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(frame_tank), vbox_tank);
	gtk_widget_show(vbox_tank);
	
	// The tank, created with a function (giw_tank_new_with_adjustment) wich doesn't need a adjustment
	tank = giw_tank_new_with_adjustment(50, 0, 100);
	gtk_box_pack_start(GTK_BOX(vbox_tank), tank, TRUE, TRUE, 0);
	gtk_widget_show (tank);
		
	spin_value=gtk_spin_button_new_with_range(-10000, 10000, 0.000001);
	gtk_box_pack_start(GTK_BOX(vbox_tank), spin_value, FALSE, FALSE, 0);
	gtk_widget_show(spin_value);

	// vbox to separate the configuration and set range/value widgets
	vbox1=gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(hbox1), vbox1, FALSE, FALSE, 0);
	gtk_widget_show(vbox1);
	
	// Frame to the configuration widgets
	frame_config=gtk_frame_new("Configuration:");
	gtk_box_pack_start(GTK_BOX(vbox1), frame_config, TRUE, TRUE, 0);
	gtk_widget_show(frame_config);
	
	table_config=gtk_table_new(4, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_config), table_config);
	gtk_widget_show(table_config);
		
	label_major=gtk_label_new("Major ticks:");
	gtk_table_attach(GTK_TABLE(table_config), label_major, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_major); 
  
	spin_major=gtk_spin_button_new_with_range(0, 50, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_major, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_major);
	
	label_minor=gtk_label_new("Minor ticks:");
	gtk_table_attach(GTK_TABLE(table_config), label_minor, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_minor); 
  
	spin_minor=gtk_spin_button_new_with_range(0, 50, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_minor, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_minor);
	
	label_legends_digits=gtk_label_new("Legends digits:");
	gtk_table_attach(GTK_TABLE(table_config), label_legends_digits, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_legends_digits); 
	
	spin_legends_digits=gtk_spin_button_new_with_range(0, 100, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_legends_digits, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_legends_digits);
		
	toggle_button_legends=gtk_toggle_button_new_with_label("Show legends");
	gtk_table_attach(GTK_TABLE(table_config), toggle_button_legends, 0, 2, 3, 4, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(toggle_button_legends);
			
	// Frame to the widgets wich set a new adjustment
	frame_adj=gtk_frame_new("Set new adjustment:");
	gtk_box_pack_start(GTK_BOX(vbox1), frame_adj, TRUE, TRUE, 0);
	gtk_widget_show(frame_adj);
	
	table_adj=gtk_table_new(4, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_adj), table_adj);
	gtk_widget_show(table_adj);
	
	label_adj_value=gtk_label_new("Value:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_value, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_value); 
	
	spin_adj_value=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_value, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_value);
	
	label_adj_lower=gtk_label_new("Lower:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_lower, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_lower); 
	
	spin_adj_lower=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_lower, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_lower);
	
	label_adj_upper=gtk_label_new("Upper:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_upper, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_upper); 
	
	spin_adj_upper=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_upper, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_upper);
		
	button_set_adj=gtk_button_new_with_label("Set new adjustment");
	gtk_table_attach(GTK_TABLE(table_adj), button_set_adj, 0, 2, 3, 4, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(button_set_adj);
			
	// Setting default values
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_value), 50);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_major), 3);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_minor), 1);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_legends_digits), 5);
	
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle_button_legends), TRUE);
			
	// Connecting signals
	g_signal_connect(G_OBJECT(spin_major), "value-changed", G_CALLBACK(spin_major_changed_value), NULL);
	g_signal_connect(G_OBJECT(spin_minor), "value-changed", G_CALLBACK(spin_minor_changed_value), NULL);
	g_signal_connect(G_OBJECT(spin_legends_digits), "value-changed", G_CALLBACK(spin_legends_digits_changed_value), NULL);
	
	g_signal_connect(G_OBJECT(toggle_button_legends), "toggled", G_CALLBACK(toggle_button_legends_toggled), NULL);
		
	g_signal_connect(G_OBJECT(button_set_adj), "clicked", G_CALLBACK(button_set_adj_clicked), NULL);
	
	// Setting the spin_value adjustment as the tank's adjustment
	gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON(spin_value), giw_tank_get_adjustment(GIW_TANK(tank)));
	  
	gtk_widget_show (window);
    
	gtk_main ();
  
	return 0;
}
