/* vslider_full_example.c  -  GiwVSlider full example
Copyright (C) 2006  Alexandre Pereira Bueno, Eduardo Parente Ribeiro

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

Maintainers
Alexandre Pereira Bueno - alpebu@yahoo.com.br 
James Scott Jr <skoona@users.sourceforge.net>
*/

#include <gtk/gtk.h>
#include <giwvslider.h> 

GtkWidget *window;
GtkWidget *hbox1;

GtkWidget *frame_vslider;
GtkWidget *vbox_vslider;
GtkWidget *vslider;
GtkWidget *spin_value;

GtkWidget *frame_config;
GtkWidget *table_config;
GtkWidget *label_major;
GtkWidget *spin_major;
GtkWidget *label_minor;
GtkWidget *spin_minor;
GtkWidget *label_legends_digits;
GtkWidget *spin_legends_digits;

GtkWidget *vbox1;

GtkWidget *frame_adj;
GtkWidget *table_adj;
GtkWidget *label_adj_value;
GtkWidget *spin_adj_value;
GtkWidget *label_adj_lower;
GtkWidget *spin_adj_lower;
GtkWidget *label_adj_upper;
GtkWidget *spin_adj_upper;
GtkWidget *button_set_adj;

GtkWidget *frame_mouse;
GtkWidget *vbox_mouse;
GtkWidget *radio_disable;
GtkWidget *radio_automatic;
GtkWidget *radio_delayed;


void spin_major_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new major ticks number
	giw_vslider_set_major_ticks_number(GIW_VSLIDER(vslider), gtk_spin_button_get_value(spinbutton));
}

void spin_minor_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new minor ticks number
	giw_vslider_set_minor_ticks_number(GIW_VSLIDER(vslider), gtk_spin_button_get_value(spinbutton));
}

void spin_legends_digits_changed_value(GtkSpinButton *spinbutton, gpointer user_data)
{
	// Setting new legends digits number
	giw_vslider_set_legends_digits(GIW_VSLIDER(vslider), gtk_spin_button_get_value(spinbutton));
}

void button_set_adj_clicked(GtkButton *button, gpointer user_data)
{
	GtkObject *adj;
	gdouble value , lower, upper;
	
	// Getting the new adjustment paramenters
	value=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_value));
	lower=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_lower));
	upper=gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin_adj_upper));
	
	adj=gtk_adjustment_new(value, lower, upper, 1.0, 1.0, 1.0);
	// Setting the new adjustment in the vslider and the spin_value
	giw_vslider_set_adjustment(GIW_VSLIDER(vslider), GTK_ADJUSTMENT(adj));
	gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON(spin_value), GTK_ADJUSTMENT(adj));
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_value), GTK_ADJUSTMENT(adj)->value);
}

void radio_disable_toggled(GtkRadioButton *radiobutton, gpointer user_data)
{
	// Set mouse policy to disabled
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton)))
		giw_vslider_set_mouse_policy(GIW_VSLIDER(vslider), GIW_VSLIDER_MOUSE_DISABLED);
}

void radio_automatic_toggled(GtkRadioButton *radiobutton, gpointer user_data)
{
	// Set mouse policy to update automaticaly
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton)))
		giw_vslider_set_mouse_policy(GIW_VSLIDER(vslider), GIW_VSLIDER_MOUSE_AUTOMATICALLY);
}

void radio_disable_delayed(GtkRadioButton *radiobutton, gpointer user_data)
{
	// Set mouse policy to update delayed
	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton)))
		giw_vslider_set_mouse_policy(GIW_VSLIDER(vslider), GIW_VSLIDER_MOUSE_DELAYED);
}

int main (int argc, char *argv[])
{
	gtk_init (&argc, &argv);

	// The main window
	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);

	gtk_window_set_title(GTK_WINDOW(window), "GiwVSlider Full Example");
    
	gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_exit), NULL);
  
	hbox1=gtk_hbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), hbox1);
	gtk_widget_show(hbox1);
	
	// Frame to the vslider 
	frame_vslider=gtk_frame_new("VSlider:");
	gtk_box_pack_start(GTK_BOX(hbox1), frame_vslider, TRUE, TRUE, 0);
	gtk_widget_show(frame_vslider);
	
	vbox_vslider=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(frame_vslider), vbox_vslider);
	gtk_widget_show(vbox_vslider);
	
	// The vslider, created with a function (giw_vslider_new_with_adjustment) wich doesn't need a adjustment
	vslider = giw_vslider_new_with_adjustment(70, 0, 100);
	gtk_box_pack_start(GTK_BOX(vbox_vslider), vslider, TRUE, TRUE, 0);
	gtk_widget_show (vslider);
		
	spin_value=gtk_spin_button_new_with_range(-10000, 10000, 0.000001);
	gtk_box_pack_start(GTK_BOX(vbox_vslider), spin_value, TRUE, TRUE, 0);
	gtk_widget_show(spin_value);
	
	// Frame to the configuration widgets
	frame_config=gtk_frame_new("Configuration:");
	gtk_box_pack_start(GTK_BOX(hbox1), frame_config, TRUE, TRUE, 0);
	gtk_widget_show(frame_config);
	
	table_config=gtk_table_new(4, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_config), table_config);
	gtk_widget_show(table_config);
		
	label_major=gtk_label_new("Major ticks:");
	gtk_table_attach(GTK_TABLE(table_config), label_major, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_major); 
  
	spin_major=gtk_spin_button_new_with_range(0, 50, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_major, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_major);
	
	label_minor=gtk_label_new("Minor ticks:");
	gtk_table_attach(GTK_TABLE(table_config), label_minor, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_minor); 
  
	spin_minor=gtk_spin_button_new_with_range(0, 50, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_minor, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_minor);
	
	label_legends_digits=gtk_label_new("Legends digits:");
	gtk_table_attach(GTK_TABLE(table_config), label_legends_digits, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_legends_digits); 
	
	spin_legends_digits=gtk_spin_button_new_with_range(0, 100, 1);
	gtk_table_attach(GTK_TABLE(table_config), spin_legends_digits, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_legends_digits);
		
	// Hbox to separate the adjustment and mouse frames
	vbox1=gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(hbox1), vbox1, TRUE, TRUE, 0);
	gtk_widget_show(vbox1);
		
	// Frame to the widgets wich set a new adjustment
	frame_adj=gtk_frame_new("Set new adjustment:");
	gtk_box_pack_start(GTK_BOX(vbox1), frame_adj, TRUE, TRUE, 0);
	gtk_widget_show(frame_adj);
	
	table_adj=gtk_table_new(4, 2, FALSE);
	gtk_container_add(GTK_CONTAINER(frame_adj), table_adj);
	gtk_widget_show(table_adj);
	
	label_adj_value=gtk_label_new("Value:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_value, 0, 1, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_value); 
	
	spin_adj_value=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_value, 1, 2, 0, 1, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_value);
	
	label_adj_lower=gtk_label_new("Lower:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_lower, 0, 1, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_lower); 
	
	spin_adj_lower=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_lower, 1, 2, 1, 2, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_lower);
	
	label_adj_upper=gtk_label_new("Upper:");
	gtk_table_attach(GTK_TABLE(table_adj), label_adj_upper, 0, 1, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(label_adj_upper); 
	
	spin_adj_upper=gtk_spin_button_new_with_range(-10000, 10000, 10);
	gtk_table_attach(GTK_TABLE(table_adj), spin_adj_upper, 1, 2, 2, 3, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(spin_adj_upper);
		
	button_set_adj=gtk_button_new_with_label("Set new adjustment");
	gtk_table_attach(GTK_TABLE(table_adj), button_set_adj, 0, 2, 3, 4, GTK_EXPAND, GTK_EXPAND, 0, 0);
	gtk_widget_show(button_set_adj);
	
	// Frame to the widgets wich set mouse policy
	frame_mouse=gtk_frame_new("Mouse policy:");
	gtk_box_pack_start(GTK_BOX(vbox1), frame_mouse, TRUE, TRUE, 0);
	gtk_widget_show(frame_mouse);
	
	vbox_mouse=gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(frame_mouse), vbox_mouse);
	gtk_widget_show(vbox_mouse);
	
	radio_disable=gtk_radio_button_new_with_label(NULL, "Disabled");
	gtk_box_pack_start(GTK_BOX(vbox_mouse), radio_disable, TRUE, FALSE, 0);
	gtk_widget_show(radio_disable);
	
	radio_automatic=gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_disable), "Update automatically");
	gtk_box_pack_start(GTK_BOX(vbox_mouse), radio_automatic, TRUE, FALSE, 0);
	gtk_widget_show(radio_automatic);
	
	radio_delayed=gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(radio_disable), "Update delayed");
	gtk_box_pack_start(GTK_BOX(vbox_mouse), radio_delayed, TRUE, FALSE, 0);
	gtk_widget_show(radio_delayed);
		
	// Setting default values
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_value), 50);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_major), 3);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_minor), 1);
	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin_legends_digits), 3);
		
	// Connecting signals
	g_signal_connect(G_OBJECT(spin_major), "value-changed", G_CALLBACK(spin_major_changed_value), NULL);
	g_signal_connect(G_OBJECT(spin_minor), "value-changed", G_CALLBACK(spin_minor_changed_value), NULL);
	g_signal_connect(G_OBJECT(spin_legends_digits), "value-changed", G_CALLBACK(spin_legends_digits_changed_value), NULL);
			
	g_signal_connect(G_OBJECT(button_set_adj), "clicked", G_CALLBACK(button_set_adj_clicked), NULL);
	
	g_signal_connect(G_OBJECT(radio_disable), "toggled", G_CALLBACK(radio_disable_toggled), NULL);
	g_signal_connect(G_OBJECT(radio_automatic), "toggled", G_CALLBACK(radio_automatic_toggled), NULL);
	g_signal_connect(G_OBJECT(radio_delayed), "toggled", G_CALLBACK(radio_disable_delayed), NULL);
	
	// Setting the right radio button
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_automatic), TRUE);

	// Setting the spin_value adjustment as the vslider's adjustment
	gtk_spin_button_set_adjustment(GTK_SPIN_BUTTON(spin_value), giw_vslider_get_adjustment(GIW_VSLIDER(vslider)));
	  
	gtk_widget_show (window);
    	
	gtk_main ();
  
	return 0;
}
